| inspect_loom | R Documentation |
Internal helper that reads the HDF5 structure of a Loom file and reports its dimensions, layers, cell and feature attributes, graphs, and a sample of cell names when available.
inspect_loom(obj)
obj |
Path to a Loom file. |
Invisibly returns a list containing information about the Loom file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.