inspect_sce: Inspect a SingleCellExperiment object

View source: R/inspect_sc.R

inspect_sceR Documentation

Inspect a SingleCellExperiment object

Description

Internal helper that reports the structure of a SingleCellExperiment object, including its dimensions, assays, reduced dimensions, alternative experiments, cell metadata, feature metadata, and a sample of cell names.

Usage

inspect_sce(obj)

Arguments

obj

A SingleCellExperiment object.

Value

Invisibly returns a list containing information about the SingleCellExperiment object.


scFlex documentation built on Sept. 29, 2026, 5:10 p.m.