| inspect_seurat | R Documentation |
Internal helper that reports the structure of a Seurat object, including its dimensions, assays, default assay structure, reductions, graphs, neighbors, metadata columns, and a sample of cell names.
inspect_seurat(obj)
obj |
A Seurat object. |
Invisibly returns a list containing information about the Seurat object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.