| convert_loom_to_anndata | R Documentation |
Reads a Loom file through AnnData and writes the resulting object as H5AD while preserving components supported by the Loom-to-AnnData reader.
convert_loom_to_anndata(input, output)
input |
Path to an input |
output |
Path to the output |
Loom is a more limited interchange format than Seurat, SingleCellExperiment, or AnnData, so only components representable by the current mapping are preserved.
The output path, returned invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.