View source: R/convert_seurat.R
| convert_seu_classic_to_v5 | R Documentation |
Converts a selected classic Seurat Assay to a Seurat v5 Assay5
while preserving the supported assay data and object structure.
convert_seu_classic_to_v5(input, output, assay = "RNA")
input |
Path to an input Seurat |
output |
Path to the output Seurat |
assay |
Name of the assay to convert. Defaults to |
The output path, returned invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.