| convert_seurat_to_loom | R Documentation |
Reads a Seurat RDS object and writes a Loom file using loompy, preserving supported expression matrices, attributes, and reductions where representable.
convert_seurat_to_loom(input, output)
input |
Path to an input Seurat |
output |
Path to the output |
Loom is a more limited interchange format than Seurat, SingleCellExperiment, or AnnData, so only components representable by the current mapping are preserved.
The output path, returned invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.