| inspect_anndata | R Documentation |
Internal helper that reads an H5AD file and reports its dimensions, primary matrix, layers, cell-level matrices, graphs, feature-level matrices, unstructured metadata, raw data, metadata columns, and a sample of cell names.
inspect_anndata(path_to_file)
path_to_file |
Path to an H5AD file. |
Invisibly returns a list containing information about the AnnData object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.