| inspect_rds_object | R Documentation |
Internal helper that identifies whether an object read from an RDS file is a Seurat or SingleCellExperiment object and dispatches it to the corresponding inspection function.
inspect_rds_object(obj)
obj |
An R object read from an RDS file. |
Invisibly returns a list containing information about the object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.