| inspect_sce | R Documentation |
Internal helper that reports the structure of a SingleCellExperiment object, including its dimensions, assays, reduced dimensions, alternative experiments, cell metadata, feature metadata, and a sample of cell names.
inspect_sce(obj)
obj |
A SingleCellExperiment object. |
Invisibly returns a list containing information about the SingleCellExperiment object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.